@@ -34,7 +34,7 @@ from urllib.error import HTTPError
 from urllib.parse import urlparse
 from urllib.request import Request, urlopen
 
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 __all__ = ["Configuration", "FHIRSpec", "download", "filename_from_response"]
 
@@ -414,7 +414,7 @@ class FHIRSpec:
                     f'Expecting "resourceType" to be present, but is not in {filepath}'
                 )
             if "Bundle" != parsed["resourceType"]:
-                raise Exception('Can only process "Bundle" resources')
+                raise Exception('Can only process "Bundle" resources')
             if "entry" not in parsed:
                 raise Exception(f"There are no entries in the Bundle at {filepath}")
 
@@ -1159,6 +1159,7 @@ class FHIRStructureDefinitionElement:
         # to a ValueSet that is a CodeSystem generating an enum
         self.enum: Optional[Dict[str, Any]] = None
         self.is_main_profile_element: bool = is_main_profile_element
+        self.represents_class: bool = False
 
         self._superclass_name: Optional[str] = None
         self._did_resolve_dependencies: bool = False
@@ -1189,6 +1190,14 @@ class FHIRStructureDefinitionElement:
         self.is_summary = element_dict.get("isSummary", False)
 
     def resolve_dependencies(self) -> None:
+        if self.is_main_profile_element:
+            self.represents_class = True
+        if (
+            not self.represents_class
+            and self.children is not None
+            and len(self.children) > 0
+        ):
+            self.represents_class = True
         if self.definition is not None:
             self.definition.resolve_dependencies()
 
@@ -1215,7 +1224,7 @@ class FHIRStructureDefinitionElement:
         second item in the tuple.
         """
         assert self._did_resolve_dependencies
-        if not self.is_main_profile_element:
+        if not self.represents_class:
             return None, None
 
         class_name = self.name_if_class()  # noqa: F841
@@ -1584,7 +1593,7 @@ class FHIRClass:
         """Returns an existing class or creates one for the given element.
         Returns a tuple with the class and a bool indicating creation.
         """
-        assert element.is_main_profile_element
+        assert element.represents_class
         class_name = element.name_if_class()
         if class_name in cls.__known_classes__:
             return cls.__known_classes__[class_name], False
@@ -1609,7 +1618,7 @@ class FHIRClass:
         """
         :param element: FHIRStructureDefinitionElement
         """
-        assert element.is_main_profile_element
+        assert element.represents_class
         self.path: Optional[str] = element.path
         self.name: str = element.name_if_class()
         self.module: Optional[str] = None
